[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

darin darin at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 07:15:12 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit a3f4f106a6ef585821ee74d17d1d88024c4139fb
Author: darin <darin at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Mon Dec 16 01:03:28 2002 +0000

            Reviewed by Trey.
    
    	- fixed 3128260 -- REGRESSION: context menus in frames are always the generic page menu
    
            * WebView.subproj/WebHTMLViewPrivate.m: (-[WebHTMLView hitTest:]):
    	Check the control key in the mouse down event. If it's down, then do no magic.
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@3067 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index e126d8a..68bcc41 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,5 +1,14 @@
 2002-12-15  Darin Adler  <darin at apple.com>
 
+        Reviewed by Trey.
+
+	- fixed 3128260 -- REGRESSION: context menus in frames are always the generic page menu
+
+        * WebView.subproj/WebHTMLViewPrivate.m: (-[WebHTMLView hitTest:]):
+	Check the control key in the mouse down event. If it's down, then do no magic.
+
+2002-12-15  Darin Adler  <darin at apple.com>
+
         Reviewed by Dave.
 
 	- fixed 3128651 -- REGRESSION: Mouse wheeling is busted on frames pages
diff --git a/WebKit/WebView.subproj/WebHTMLViewPrivate.m b/WebKit/WebView.subproj/WebHTMLViewPrivate.m
index e0cceeb..363b405 100644
--- a/WebKit/WebView.subproj/WebHTMLViewPrivate.m
+++ b/WebKit/WebView.subproj/WebHTMLViewPrivate.m
@@ -271,9 +271,22 @@ static BOOL forceRealHitTest = NO;
 
 - (NSView *)hitTest:(NSPoint)point
 {
-    // WebHTMLView objects handle all clicks for objects inside them.
-    BOOL realHitTest = forceRealHitTest || [[[self window] currentEvent] type] != NSLeftMouseDown;
-    return realHitTest ? [super hitTest:point] : [[self superview] mouse:point inRect:[self frame]] ? self : nil;
+    // WebHTMLView objects handle all left mouse clicks for objects inside them.
+    // That does not include left mouse clicks with the control key held down.
+    BOOL captureHitsOnSubviews;
+    if (forceRealHitTest) {
+        captureHitsOnSubviews = NO;
+    } else {
+        NSEvent *event = [[self window] currentEvent];
+        captureHitsOnSubviews = [event type] == NSLeftMouseDown && ([event modifierFlags] & NSControlKeyMask) == 0;
+    }
+    if (!captureHitsOnSubviews) {
+        return [super hitTest:point];
+    }
+    if ([[self superview] mouse:point inRect:[self frame]]) {
+        return self;
+    }
+    return nil;
 }
 
 - (void)_updateMouseoverWithEvent:(NSEvent *)event

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list